// https://nuxt.com/docs/api/configuration/nuxt-config
export default defineNuxtConfig({
  devtools: {
    enabled: true,

    timeline: {
      enabled: true,
    },
  },

  app: {
    head: {
      title: 'ABENES SARL',
      meta: [
        {
          name: 'description',
          content: 'ABENES SARL société d\'equipement medical et de laboratoire'
        },
        {
          name: 'keywords',
          content: 'equipement medical, laboratoire, abenes, sarl, abenes sarl, abenes-sarl, abenes-sarl.com'
        },
        {
          name: 'author',
          content: 'AVA TECH SARL'
        },
        {
          name: 'viewport',
          content: 'width=device-width, initial-scale=1.0'
        },
        {
          name: 'robots',
          content: 'index, follow'
        },
        {
          name: 'googlebot',
          content: 'index, follow'
        },
        {
          name: 'google',
          content: 'nositelinkssearchbox'
        },
        {
          name: 'og:title',
          content: 'ABENES SARL'
        },
        {
          name: 'og:description',
          content: 'ABENES SARL société de distribution d\'equipement medical et de laboratoire. Nous sommes spécialisés dans la vente et la maintenance des équipements médicaux et de laboratoire. Nous exerçons dans le domaine de la santé depuis 2016. Nous sommes basés à Cotnou, BENIN.'
        },
        {
          name: 'og:image',
          content: 'https://abenes.bj/assets/img/logo/logo.png'
        },
        {
          name: 'og:url',
          content: 'https://www.abenes.bj'
        },
        {
          name: 'og:site_name',
          content: 'ABENES SARL'
        },
        {
          name: 'og:locale',
          content: 'fr_BJ'
        },
        {
          name: 'og:type',
          content: 'website'
        },
        {
          name: 'twitter:card',
          content: 'summary'
        },
        {
          name: 'twitter:title',
          content: 'ABENES SARL'
        },
        {
          name: 'twitter:description',
          content: 'ABENES SARL société de distribution d\'equipement medical et de laboratoire. Nous sommes spécialisés dans la vente et la maintenance des équipements médicaux et de laboratoire. Nous exerçons dans le domaine de la santé depuis 2016. Nous sommes basés à Cotnou, BENIN.'
        },
        {
          name: 'twitter:image',
          content: 'https://abenes.bj/assets/img/logo/logo.png'
        },
        {
          name: 'twitter:url',
          content: 'https://www.abenes.bj'
        },
        {
          name: 'charset',
          content: 'utf-8'
        },
        {
          name: 'hreflang',
          content: 'fr'
        }




      ],
      script: [
        


       
      ],
      link: [
        { rel: 'icon', type: 'image/x-icon', href: 'favicon.ico' },

      ]

    }

  },

  css: [
    'bootstrap/dist/css/bootstrap.css',
    '@/assets/css/main.css',
    '@/assets/css/all.min.css',
    '@/assets/css/animate.css',
    '@/assets/css/default.css',
    '@/assets/css/font-futuraPT.css',
    '@/assets/css/icomoon.css',
    '@/assets/css/jquery.fancybox.min.css',
    '@/assets/css/jquery-ui.css',
    '@/assets/css/meanmenu.css',
    '@/assets/css/nice-select.css',
    '@/assets/css/responsive.css',
    '@/assets/css/slick.css',
    '@/assets/css/dashboard3.css'

  ],
  

  modules: ['@nuxt/image', 'nuxt-swiper', 'nuxt-mongoose', '@sidebase/nuxt-auth', 'nuxt-bootstrap-icons', '@vite-pwa/nuxt', '@vue-email/nuxt'],


  image: {
    inject: true
  },
  mongoose: {
    uri: process.env.MONGODB_URI,
    options: {},
    modelsDir: 'models',
  },
  runtimeConfig: {
    baseURL: process.env.BASE_URL ,
    MONGODB_URI: process.env.MONGODB_URI ,
    AUTH_SECRET: process.env.API_SECRET,
    NUXT_AUTH_ORIGIN: process.env.NUXT_AUTH_ORIGIN,
    SMTP_HOST: process.env.SMTP_HOST,
    SMTP_PORT: process.env.SMTP_PORT,
    SMTP_USER: process.env.SMTP_USER,
    SMTP_PASS: process.env.SMTP_PASS,



  },
  auth: {
    
    baseURL: process.env.NUXT_AUTH_ORIGIN,
    provider: {
      type: 'authjs'
    },
    
  },

pwa:{
  manifest:{
    name: 'ABENES SARL',
    short_name: 'ABENES SARL',
    description: 'ABENES SARL société d\'equipement medical et de laboratoire',
    lang: 'fr',
    theme_color: '#FFFFFF',
    background_color: '#FFFFFF',
    display: 'standalone',
    start_url: '/',
    scope: '/',
    icons: [
      {
        src: '/icon.png',
        sizes: '512x512',
        type: 'image/png',
        purpose: 'any maskable'
      }
    ],
    
  },
  workbox: {
    globPatterns: ['**/*.{js,css,html,png,svg,ico}'],
  },
  client: {
    installPrompt: true,
    // you don't need to include this: only for testing purposes
    // if enabling periodic sync for update use 1 hour or so (periodicSyncForUpdates: 3600)
    periodicSyncForUpdates: 2000000,
  },
  devOptions: {
    enabled: true,
    suppressWarnings: true,
    navigateFallbackAllowlist: [/^\/$/],
    type: 'module',
  },

  
},
vueEmail :{
  baseUrl: process.env.NUXT_AUTH_ORIGIN,
  autoImport: true,
  playground: true,
  
},







})